[pypy-svn] r7798 - pypy/trunk/src/pypy/annotation

arigo at codespeak.net arigo at codespeak.net
Thu Dec 9 23:01:02 CET 2004


Author: arigo
Date: Thu Dec  9 23:01:02 2004
New Revision: 7798

Modified:
   pypy/trunk/src/pypy/annotation/bookkeeper.py
Log:
Too much specialization: don't need to specialize for the case of a *arg in a
call to a function expecting a *arg.


Modified: pypy/trunk/src/pypy/annotation/bookkeeper.py
==============================================================================
--- pypy/trunk/src/pypy/annotation/bookkeeper.py	(original)
+++ pypy/trunk/src/pypy/annotation/bookkeeper.py	Thu Dec  9 23:01:02 2004
@@ -222,8 +222,9 @@
             else:
                 raise Exception, "unsupported specialization type '%s'"%(x,)
 
-        elif func.func_code.co_flags & CO_VARARGS:
-            # calls to *arg functions: create one version per number of args
+        elif func.func_code.co_flags & CO_VARARGS and args.w_stararg is None:
+            # calls to *arg functions without an incoming w_stararg:
+            # create one version per number of args
             assert not args.kwds_w, (
                 "keyword forbidden in calls to *arg functions")
             nbargs = len(args.arguments_w)



More information about the Pypy-commit mailing list